Users Guide
===========

GEOUNED can be used as a Python package with the API or as a command line tool with the CLI.


.. toctree::
   :maxdepth: 2

   installation/index
   execution_settings/index
   simplification
   material_allocation
   void_generation
